.. _getting_started:

===============
Getting started
===============

Quick installation
====================

.. code-block:: console

   pip install boario

In depth instructions ?
-------------------------

See the :ref:`installation` page.


.. include:: ../../README.rst
   :start-line: 41

.. toctree::
   :maxdepth: 1
   :hidden:

   boario-installation
